@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.953 2020/05/08 16:44:41 landry Exp $
+# $OpenBSD: Quirks.pm,v 1.953.2.1 2020/08/24 15:10:21 kmos Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -1700,6 +1700,7 @@ my $cve = {
 	'lang/php/7.2,-main' => 'php->7.2,<7.2.18',
 	'lang/php/7.3,-main' => 'php->7.3,<7.3.5',
 	'lang/python/2.7,-main' => 'python->2.7,<2.7.16',
+	'lang/python/3.7,-main' => 'python->3.7,<3.7.9',
 	'lang/ruby/2.3,-main' => 'ruby-<2.3.8',
 	'lang/ruby/2.4,-main' => 'ruby->2.4,<2.4.5p2',
 	'lang/ruby/2.5,-main' => 'ruby->2.5,<2.5.5',
